==> mandelbulber2_2.10.orig.tar.gz: mandelbulber2-2.10/src/thumbnail.hpp <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2014-17 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Krzysztof Marczak (buddhi1980@gmail.com)
 *
 * cThumbnail class - thumbnail rendering
 */

#ifndef MANDELBULBER2_SRC_THUMBNAIL_HPP_
#define MANDELBULBER2_SRC_THUMBNAIL_HPP_

#include <QtCore>

// forward declarations
class cParameterContainer;
class cFractalContainer;
class cImage;

class cThumbnail
{
public:
	cThumbnail(const cParameterContainer *_params, const cFractalContainer *_fractal, int _width,
		int _height, const QString &_hash);
	~cThumbnail();
	void AssignWidget(QWidget *widget) { qwidget = widget; }
	QPixmap Render();
	void Save(QString filename) const;

private:
	cImage *image;
	const cParameterContainer *params;
	const cFractalContainer *fractal;
	QWidget *qwidget;
	const int width;
	const int height;
	QString hash;
};

#endif /* MANDELBULBER2_SRC_THUMBNAIL_HPP_ */

==> mandelbulber2-2.33.tar.gz: mandelbulber2-2.33/src/thumbnail.hpp <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2014-20 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Krzysztof Marczak (buddhi1980@gmail.com)
 *
 * cThumbnail class - thumbnail rendering
 */

#ifndef MANDELBULBER2_SRC_THUMBNAIL_HPP_
#define MANDELBULBER2_SRC_THUMBNAIL_HPP_

#include <memory>

#include <QPixmap>
#include <QString>

// forward declarations
class cParameterContainer;
class cFractalContainer;
class cImage;

class cThumbnail
{
public:
	cThumbnail(const std::shared_ptr<cParameterContainer> _params,
		const std::shared_ptr<cFractalContainer> _fractal, int _width, int _height, QString _hash);
	~cThumbnail();
	void AssignWidget(QWidget *widget) { qWidget = widget; }
	QPixmap Render();
	void Save(QString filename) const;

private:
	std::shared_ptr<cImage> image;
	const std::shared_ptr<cParameterContainer> params;
	const std::shared_ptr<cFractalContainer> fractal;
	QWidget *qWidget;
	const int width;
	const int height;
	QString hash;
};

#endif /* MANDELBULBER2_SRC_THUMBNAIL_HPP_ */
